@@ -122,9 +122,16 @@ struct ccsecurity_operations {
 				   const char *from);
 	int (*truncate_permission) (struct dentry *dentry,
 				    struct vfsmount *mnt);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 19, 0)
+	int (*rename_permission) (struct dentry *old_dentry,
+				  struct dentry *new_dentry,
+				  struct vfsmount *mnt,
+				  const unsigned int flags);
+#else
 	int (*rename_permission) (struct dentry *old_dentry,
 				  struct dentry *new_dentry,
 				  struct vfsmount *mnt);
+#endif
 	int (*link_permission) (struct dentry *old_dentry,
 				struct dentry *new_dentry,
 				struct vfsmount *mnt);
@@ -360,6 +367,17 @@ static inline int ccs_truncate_permission(struct dentry *dentry,
 	return func ? func(dentry, mnt) : 0;
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 19, 0)
+static inline int ccs_rename_permission(struct dentry *old_dentry,
+					struct dentry *new_dentry,
+					struct vfsmount *mnt,
+					const unsigned int flags)
+{
+	int (*func) (struct dentry *, struct dentry *, struct vfsmount *,
+		     const unsigned int) = ccsecurity_ops.rename_permission;
+	return func ? func(old_dentry, new_dentry, mnt, flags) : 0;
+}
+#else
 static inline int ccs_rename_permission(struct dentry *old_dentry,
 					struct dentry *new_dentry,
 					struct vfsmount *mnt)
@@ -368,6 +386,7 @@ static inline int ccs_rename_permission(struct dentry *old_dentry,
 		= ccsecurity_ops.rename_permission;
 	return func ? func(old_dentry, new_dentry, mnt) : 0;
 }
+#endif
 
 static inline int ccs_link_permission(struct dentry *old_dentry,
 				      struct dentry *new_dentry,
@@ -597,12 +616,22 @@ static inline int ccs_truncate_permission(struct dentry *dentry,
 	return 0;
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 19, 0)
+static inline int ccs_rename_permission(struct dentry *old_dentry,
+					struct dentry *new_dentry,
+					struct vfsmount *mnt,
+					const unsigned int flafs)
+{
+	return 0;
+}
+#else
 static inline int ccs_rename_permission(struct dentry *old_dentry,
 					struct dentry *new_dentry,
 					struct vfsmount *mnt)
 {
 	return 0;
 }
+#endif
 
 static inline int ccs_link_permission(struct dentry *old_dentry,
 				      struct dentry *new_dentry,
